@@ -7,9 +7,9 @@ Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 import re
 import logging
 import sys
+import threading
 from collections import MutableMapping
 from contextlib import closing
-from Pyro4.threadutil import Lock
 from Pyro4.errors import NamingError
 
 try:
@@ -29,14 +29,13 @@ except ImportError:
     sqlite3 = None
 
 
-__all__ = ["SqlStorage", "DbmStorage"]
-
 log = logging.getLogger("Pyro4.naming_storage")
 
 
 class SqlStorage(MutableMapping):
     """
-    Sqlite-based storage, in just a single (name,uri) table.
+    Sqlite-based storage.
+    It is just a single (name,uri) table for the names and another table for the metadata.
     Sqlite db connection objects aren't thread-safe, so a new connection is created in every method.
     """
     def __init__(self, dbfile):
@@ -252,7 +251,7 @@ class DbmStorage(MutableMapping):
         self.dbmfile = dbmfile
         db = dbm.open(self.dbmfile, "c", mode=0o600)
         db.close()
-        self.lock = Lock()
+        self.lock = threading.Lock()
 
     def __getattr__(self, item):
         raise NotImplementedError("DbmStorage doesn't implement method/attribute '"+item+"'")
@@ -349,8 +348,7 @@ class DbmStorage(MutableMapping):
     def optimized_regex_list(self, regex, return_metadata=False):
         try:
             regex = re.compile(regex + "$")  # add end of string marker
-        except re.error:
-            x = sys.exc_info()[1]
+        except re.error as x:
             raise NamingError("invalid regex: " + str(x))
         with self.lock:
             try:
